@@ -12,17 +12,17 @@ cat $TMPDIR/used
 echo
 echo "Unused patches"
 echo "=============="
-fgrep -v -f $TMPDIR/used $TMPDIR/avail || test $? = 1
+grep -F -v -f $TMPDIR/used $TMPDIR/avail || test $? = 1
 echo
 echo "Patches without required headers"
 echo "================================"
-xargs egrep -l '^(Subject|Description):' < $TMPDIR/used | xargs egrep -l '^(From|Author|Origin):' > $TMPDIR/goodheaders || test $? = 1
-fgrep -v -f $TMPDIR/goodheaders $TMPDIR/used || test $? = 1
+xargs grep -E -l '^(Subject|Description):' < $TMPDIR/used | xargs grep -E -l '^(From|Author|Origin):' > $TMPDIR/goodheaders || test $? = 1
+grep -F -v -f $TMPDIR/goodheaders $TMPDIR/used || test $? = 1
 echo
 echo "Patches without Origin or Forwarded header"
 echo "=========================================="
-xargs egrep -L '^(Origin:|Forwarded: (no\b|not-needed|http))' < $TMPDIR/used || test $? = 1
+xargs grep -E -L '^(Origin:|Forwarded: (no\b|not-needed|http))' < $TMPDIR/used || test $? = 1
 echo
 echo "Patches to be forwarded"
 echo "======================="
-xargs egrep -l '^Forwarded: no\b' < $TMPDIR/used || test $? = 1
+xargs grep -E -l '^Forwarded: no\b' < $TMPDIR/used || test $? = 1
